package com.accesscompany.testlistadapter;

import java.util.ArrayList;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageButton;
import android.widget.ListView;
import android.widget.TextView;

public class MainActivity extends Activity {
	private static final String TAG = "MainActivity";
	
	// My Adapter, based on BaseAdapter
	private MyListAdapter mAdapter = null;
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        mAdapter = new MyListAdapter();
        for (int i = 0; i < 50; i++) {
            MyListItem list_item = new MyListItem();
            list_item.setTitle("title" + i);
            list_item.setText("text" + i);
            mAdapter.addItem(list_item);
        }
        
        ListView mainList = (ListView)findViewById(R.id.mainlist);
        mainList.setAdapter(mAdapter);
    }
 
    private OnClickListener listenBtnListener = new OnClickListener() {
    	public void onClick(View v) {
    		Log.i(TAG, "Clicked view: " + v + ", parent: " + v.getParent());
    		ViewHolder vh = (ViewHolder)((View)v.getParent()).getTag();
    		
			AlertDialog.Builder ad = new AlertDialog.Builder(MainActivity.this);
			ad.setTitle("Listen button clicked");
			ad.setMessage("The " + vh.position + " listen button clicked");
			ad.setPositiveButton("Okay", new DialogInterface.OnClickListener() {
    	        public void onClick(DialogInterface dialog, int id) {
    	        	Log.i(TAG, "Listen button click dialog disposing...");
    	        }
    	    });
			ad.show();
		}
    };
    
    private OnClickListener downloadBtnListener = new OnClickListener() {
    	public void onClick(View v) {
    		Log.i(TAG, "Clicked view: " + v + ", parent: " + v.getParent());
    		ViewHolder vh = (ViewHolder)((View)v.getParent()).getTag();
    		
			AlertDialog.Builder ad = new AlertDialog.Builder(MainActivity.this);
			ad.setTitle("Download button clicked");
			ad.setMessage("The " + vh.position + " download button clicked");
			ad.setPositiveButton("Okay", new DialogInterface.OnClickListener() {
    	        public void onClick(DialogInterface dialog, int id) {
    	        	Log.i(TAG, "Download button click dialog disposing...");
    	        }
    	    });
			ad.show();
		}
    };
    
    private class MyListAdapter extends BaseAdapter {
 
        private ArrayList<MyListItem> mData = new ArrayList<MyListItem>();
        private LayoutInflater mInflater;
 
        public MyListAdapter() {
            mInflater = (LayoutInflater)getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        }
 
        public void addItem(MyListItem item) {
            mData.add(item);
            notifyDataSetChanged();
        }
 
        @Override
        public int getCount() {
            return mData.size();
        }
 
        @Override
        public MyListItem getItem(int position) {
            return mData.get(position);
        }
 
        @Override
        public long getItemId(int position) {
            return position;
        }
 
        @Override
        public View getView(int position, View convertView, ViewGroup parent) {
            Log.i(TAG, "getView " + position + " " + convertView + "; parent: " + parent);
            ViewHolder holder = null;
            if (convertView == null) {
                convertView = mInflater.inflate(R.layout.listitem_layout, null);
                holder = new ViewHolder();
                holder.tvTitle = (TextView)convertView.findViewById(R.id.itemTitle);
                holder.tvText = (TextView)convertView.findViewById(R.id.itemText);
                holder.btnListen = (ImageButton)convertView.findViewById(R.id.btnListen);
                holder.btnDownload = (ImageButton)convertView.findViewById(R.id.btnDownload);
                holder.position = position;
                convertView.setTag(holder);
            } else {
                holder = (ViewHolder)convertView.getTag();
            }
            holder.tvTitle.setText(mData.get(position).getTitle());
            holder.tvText.setText(mData.get(position).getText());
            holder.btnListen.setImageResource(R.drawable.icon);
            holder.btnListen.setOnClickListener(listenBtnListener);
            holder.btnDownload.setImageResource(R.drawable.icon);
            holder.btnDownload.setOnClickListener(downloadBtnListener);
            
            return convertView;
        }
 
    }
 
    public class ViewHolder {
        public TextView tvTitle;
        public TextView tvText;
        public ImageButton btnListen;
        public ImageButton btnDownload;
        public int position;
    }
}